pub struct Command {
pub description: String,
pub id: i64,
pub name: String,
}Expand description
Command descriptor from the running simulator session.
JSON schema
{
"description": "Command descriptor from the running simulator session.",
"type": "object",
"required": [
"description",
"id",
"name"
],
"properties": {
"description": {
"description": "Human-readable command description.",
"type": "string"
},
"id": {
"description": "Session-local numeric identifier used to activate and subscribe to this command during the current simulator run.\n",
"type": "integer",
"format": "int64"
},
"name": {
"description": "Fully qualified command name.",
"type": "string"
}
}
}Fields
description: StringHuman-readable command description.
id: i64Session-local numeric identifier used to activate and subscribe to this command during the current simulator run.
name: StringFully qualified command name.