pub struct Dataref {
pub id: i64,
pub name: String,
pub value_type: DatarefValueType,
}Expand description
Dataref descriptor from the running simulator session.
JSON schema
{
"description": "Dataref descriptor from the running simulator session.",
"type": "object",
"required": [
"id",
"name",
"value_type"
],
"properties": {
"id": {
"description": "Session-local numeric identifier used to read, write, and subscribe to this dataref during the current simulator run.\n",
"type": "integer",
"format": "int64"
},
"name": {
"description": "Fully qualified dataref name.",
"type": "string"
},
"value_type": {
"description": "Dataref value kind: `float`, `double`, `int`, `int_array`, `float_array`, or `data` (binary represented as base64 text).\n",
"type": "string",
"enum": [
"float",
"double",
"int",
"int_array",
"float_array",
"data"
]
}
}
}Fields
id: i64Session-local numeric identifier used to read, write, and subscribe to this dataref during the current simulator run.
name: StringFully qualified dataref name.
value_type: DatarefValueTypeDataref value kind: float, double, int, int_array, float_array, or data (binary represented as base64 text).